#
# spec file for package python-jirafs
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-jirafs
Version:        2.2.0
Release:        bp156.3.1
Summary:        Library for editing JIRA issues as local text files
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/coddingtonbear/jirafs
Source:         https://github.com/coddingtonbear/jirafs/archive/%{version}.tar.gz
Patch0:         capitalization.patch
BuildRequires:  %{python_module PrettyTable}
BuildRequires:  %{python_module behave}
BuildRequires:  %{python_module blessings}
BuildRequires:  %{python_module environmental-override}
BuildRequires:  %{python_module ipdb}
BuildRequires:  %{python_module jira}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tox}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PrettyTable
Requires:       python-blessings
Requires:       python-environmental-override
Requires:       python-ipdb
Requires:       python-jira >= 2
BuildArch:      noarch
%python_subpackages

%description
This library lets the user stay out of JIRA by letting them edit JIRA
issues as a collection of text files using an interface inspired by
`git` and `hg`.

%prep
%setup -q -n jirafs-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# tests require running JIRA instance
#%%python_exec -m unittest discover -v

%files %{python_files}
%{_bindir}/jirafs
%{python_sitelib}/*

%changelog
* Tue Feb 25 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.2.0, partial changelog:
  * Fixes a bug in which search results from search_users were not being displayed. (Issue #61)
  * Fixes another field deletion/addition problem relating to Issue #59
  * Fixes a bug preventing the match subcommand from being able to properly obtain field values. (Issue #60)
  * Fixes several minor bugs relating to issue previews including:
  * In certain situations, the preview automatic change detection would become stuck in a loop causing the page to refresh continuously.
  * Preview document was not delivered with an UTF-8 charset, so non-latin-1 characters would be mangled.
  * Changes to Jira fields would not be refreshed when rendering preview after submitting changes.
  * Insufficient whitespace between comments may cause Jira to misinterpret headers as part of a previous comment's bulleted list.
  * Fixes bug that would cause an unhelpful traceback to be displayed if you were to run Jirafs commands outside of a ticketfolder.
  * Fixes to various bugs relating to merging upstream changes from Jira with un-pushed local changes.
  * User is now warned about conflicts were they to occur when merging-in upstream changes.
  * Conflicts are displayed on the status display should they exist, including instructions about how to resolve them.
  * Additional polish for 'preview' function including:
  * Fixes to exception display in-console for harmless errors resulting from clients navigating away.
  * Defaulting behavior such that server will automatically self-terminate when the user navigates away. If this behavior is not desired, a command-line argument --serve-forever is available.
  * Adding display of comments for 'all' preview mode.
  * Adds links allowing you to jump to the specific section you're interested in when in the 'all' preview mode.
  * Macro reversal changes for comments.read_only.jira: No longer will macros be reversed for read-only files given that the content of historical comments cannot be changed.
  * Users can now set a preferred date format by setting a configuration value main.date_format.
  * Obsolete and undocumented "Clone" functionality allowing you to clone a Jira ticketfolder from a git repository (instead of directly from a Jira issue) was removed.
  * Jira server URL inference when cloning by using an issue number instead of a ticket URL is improved to be more foolproof.
- Refreshed patch capitalization.patch
- Removed {Build,}Requires on six, not required
- Tighten Requires on python-jira
* Wed Jan 22 2020 Matej Cepl <mcepl@suse.com>
- Update to 2.0.7: too many changes, and no good changelog
* Fri Jan  3 2020 Todd R <toddrme2178@gmail.com>
- Update to 1.17.5
  * Much saner method of setting up logging.
- Update to 1.17.4
  * Adding better error messages for incorrectly-subclassed loaded plugins.
  * Updating LICENSE year range.
- Drop python2 support due to dependency dropping python2
* Thu Mar 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add missing ipdb dependency
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.17.3:
  * no upstream changelog
- Drop merged patch verlib.patch
- Rebase capitalization.patch
* Mon Mar 25 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Trim filler wording.
* Fri Jan 18 2019 Matej Cepl <mcepl@suse.com>
- Add missing Requires
* Tue Jan 15 2019 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for 1.17.1
